"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validate = void 0;
const pattern_1 = require("../pattern");
function validateParts(parts, runtime) {
    for (const part of parts) {
        if ((0, pattern_1.isExpression)(part)) {
            if (typeof runtime[part.name] !== 'function') {
                throw new ReferenceError(`Runtime function not available: ${part.name}`);
            }
            // TODO: Once runtime arg requirements are defined, test against them
        }
    }
}
/**
 * Validate a message.
 *
 * @remarks
 * Throws if `msg` is a {@link JunkMessage},
 * if it contains parse `errors`,
 * or of if references runtime functions that are not available in the `runtime`.
 *
 * Formatting a message that passes validation may still fail,
 * as it may depend on parameters that are not passed in,
 * or its runtime function calls may fail.
 *
 * @beta
 */
function validate(msg, runtime) {
    if (msg.errors?.length)
        throw new Error('Message parse failed');
    switch (msg.type) {
        case 'message':
            validateParts(msg.pattern.body, runtime);
            break;
        case 'select':
            validateParts(msg.selectors, runtime);
            for (const { value } of msg.variants)
                validateParts(value.body, runtime);
            break;
        default:
            throw new Error(`Invalid message type: ${msg.type}`);
    }
}
exports.validate = validate;
