"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extendLocaleContext = exports.isLocaleContext = void 0;
/**
 * Type guard for {@link LocaleContext}
 *
 * @beta
 */
const isLocaleContext = (lc) => !!lc &&
    typeof lc === 'object' &&
    Array.isArray(lc.locales) &&
    typeof lc.locales[0] === 'string';
exports.isLocaleContext = isLocaleContext;
/**
 * Create a new LocaleContext, using `orig` as a base.
 *
 * @beta
 * @returns `null` if both arguments are `null`
 */
function extendLocaleContext(orig, lc) {
    let { locales, localeMatcher } = orig ?? {};
    if (lc && typeof lc === 'string') {
        locales ?? (locales = [lc]);
    }
    else if (Array.isArray(lc)) {
        locales ?? (locales = lc.slice());
    }
    else if ((0, exports.isLocaleContext)(lc)) {
        locales ?? (locales = lc.locales.slice());
        localeMatcher ?? (localeMatcher = lc.localeMatcher);
    }
    return locales ? { locales, localeMatcher } : null;
}
exports.extendLocaleContext = extendLocaleContext;
