"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageDateTime = void 0;
const locale_context_1 = require("./locale-context");
const message_value_1 = require("./message-value");
const DATETIME = 'datetime';
/**
 * A child class of {@link MessageValue} for Date values.
 *
 * @beta
 */
class MessageDateTime extends message_value_1.MessageValue {
    constructor(locale, date, { meta, options, source } = {}) {
        const fmt = { meta, source };
        if (date instanceof MessageDateTime) {
            const lc = (0, locale_context_1.extendLocaleContext)(date.localeContext, locale);
            super(DATETIME, lc, date.value, fmt);
            if (options || date.options)
                this.options = date.options
                    ? { ...date.options, ...options }
                    : { ...options };
        }
        else {
            if (typeof date === 'number')
                date = new Date(date);
            if (date instanceof Date) {
                super(DATETIME, locale, date, fmt);
                if (options)
                    this.options = { ...options };
            }
            else
                throw new TypeError(`Invalid ${typeof date} as date argument`);
        }
    }
    getDateTimeFormatter() {
        const lc = this.localeContext;
        const opt = lc
            ? { localeMatcher: lc.localeMatcher, ...this.options }
            : this.options;
        return new Intl.DateTimeFormat(lc?.locales, opt);
    }
    toParts() {
        const dtf = this.getDateTimeFormatter();
        return dtf.formatToParts(this.value);
    }
    toString(onError) {
        try {
            const hasOpt = this.options && Object.keys(this.options).length > 0;
            if (hasOpt) {
                const dtf = this.getDateTimeFormatter();
                return dtf.format(this.value);
            }
            else {
                const lc = this.localeContext;
                return lc
                    ? this.value.toLocaleString(lc.locales, lc)
                    : String(this.value);
            }
        }
        catch (error) {
            if (onError)
                onError(error, this);
            if (this.value === undefined) {
                const source = this.source || message_value_1.FALLBACK_SOURCE;
                return `{${source}}`;
            }
            return String(this.value);
        }
    }
}
exports.MessageDateTime = MessageDateTime;
