"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageMarkupEnd = exports.MessageMarkupStart = void 0;
const message_value_1 = require("./message-value");
const MARKUP_START = 'markup-start';
const MARKUP_END = 'markup-end';
/**
 * A child class of {@link MessageValue} for starting markup elements.
 *
 * @beta
 */
class MessageMarkupStart extends message_value_1.MessageValue {
    constructor(locale, name, { meta, options, source }) {
        super(MARKUP_START, locale, name, { meta, source });
        this.options = { ...options };
    }
    matchSelectKey() {
        return false;
    }
    toString(onError) {
        let tag = this.value;
        for (const [key, opt] of Object.entries(this.options)) {
            try {
                if (/^\w[\w-]*$/.test(key)) {
                    let strOpt = String(opt);
                    if (/[^\w-]/.test(strOpt)) {
                        strOpt = '(' + strOpt.replace(/[()\\]/g, '\\$&') + ')';
                    }
                    tag += ` ${key}=${strOpt}`;
                }
            }
            catch (error) {
                if (onError)
                    onError(error, this);
            }
        }
        return `{+${tag}}`;
    }
}
exports.MessageMarkupStart = MessageMarkupStart;
/**
 * A child class of {@link MessageValue} for ending markup elements.
 *
 * @beta
 */
class MessageMarkupEnd extends message_value_1.MessageValue {
    constructor(locale, name, options) {
        super(MARKUP_END, locale, name, options);
    }
    matchSelectKey() {
        return false;
    }
    toString() {
        return `{-${this.value}}`;
    }
}
exports.MessageMarkupEnd = MessageMarkupEnd;
