import { Context } from '../format-context';
import { LocaleContextArg } from './locale-context';
import { MessageValue, Meta } from './message-value';
/**
 * A child class of {@link MessageValue} for numerical values.
 *
 * @beta
 */
export declare class MessageNumber extends MessageValue<number | bigint> {
    options?: Intl.NumberFormatOptions & Intl.PluralRulesOptions;
    constructor(locale: LocaleContextArg, number: number | bigint | Readonly<MessageNumber>, { meta, options, source }?: {
        meta?: Readonly<Meta>;
        options?: Readonly<Intl.NumberFormatOptions & Intl.PluralRulesOptions>;
        source?: string;
    });
    private getIntl;
    protected getPluralCategory(): Intl.LDMLPluralRule;
    /**
     * In addition to matching exact values,
     * numerical values will also match keys with the same plural rule category,
     * i.e. one of `zero`, `one`, `two`, `few`, `many`, and `other`.
     *
     * @remarks
     * Different languages use different subset of plural rule categories.
     * For example, cardinal English plurals only use `one` and `other`,
     * so a key `zero` will never be matched for that locale.
     */
    matchSelectKey(key: string): boolean | {
        plural: Intl.LDMLPluralRule;
    };
    toParts(): Intl.NumberFormatPart[];
    toString(onError?: Context['onError']): string;
}
