import { Context } from '../format-context';
import { LocaleContext, LocaleContextArg } from './locale-context';
export declare const FALLBACK_SOURCE = "???";
/**
 * Additional meta information may be attached to most nodes. In common use,
 * this information is not required when formatting a message.
 *
 * @beta
 */
export type Meta = Record<string, string>;
/**
 * Type guard for message values that may contain a `meta` member
 *
 * @beta
 */
export declare const hasMeta: <T>(part: MessageValue<T>) => part is MessageValue<T> & {
    meta: Meta;
};
/**
 * The base class of all message values.
 *
 * @beta
 */
export declare class MessageValue<T = unknown> {
    #private;
    readonly type: string;
    value: T;
    source?: string;
    meta?: Meta;
    constructor(type: string | null, locale: LocaleContextArg, value: T, format?: {
        meta?: Readonly<Meta>;
        source?: string;
        toString?: MessageValue<T>['toString'];
    });
    get localeContext(): LocaleContext | null;
    set localeContext(locale: string | string[] | LocaleContext | null);
    matchSelectKey(key: string): boolean | Meta;
    toString(onError?: Context['onError']): string;
}
