import { Message } from './data-model';
import { MessageValue, ResolvedMessage } from './message-value';
import { Runtime } from './runtime';
/** @beta */
export interface MessageFormatOptions {
    /**
     * If given multiple locales,
     * determines which algorithm to use when selecting between them;
     * the default for `Intl` formatters is `'best fit'`.
     *
     * @remarks
     * See: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl#locale_negotiation
     */
    localeMatcher?: 'best fit' | 'lookup';
    /**
     * The set of functions available during message resolution.
     * If not set, defaults to {@link defaultRuntime}.
     */
    runtime?: Runtime;
}
/**
 * Create a new message formatter.
 *
 * @beta
 */
export declare class MessageFormat {
    #private;
    constructor(source: string | Message, locales?: string | string[], options?: MessageFormatOptions);
    resolveMessage(msgParams?: Record<string, unknown>, onError?: (error: unknown, value: MessageValue | undefined) => void): ResolvedMessage;
    resolvedOptions(): {
        localeMatcher: "best fit" | "lookup";
        locales: string[];
        message: Message;
        runtime: Readonly<Runtime>;
    };
    private createContext;
}
