"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseDeclarations = void 0;
const placeholder_js_1 = require("./placeholder.js");
const util_js_1 = require("./util.js");
const values_js_1 = require("./values.js");
// Declaration ::= 'let' WhiteSpace Variable '=' '{' Expression '}'
function parseDeclarations(src, errors) {
    let pos = (0, util_js_1.whitespaces)(src, 0);
    const declarations = [];
    while (src.startsWith('let', pos)) {
        const decl = parseDeclaration(src, pos, errors);
        declarations.push(decl);
        pos = decl.end;
        pos += (0, util_js_1.whitespaces)(src, pos);
    }
    checkLocalVarReferences(declarations, errors);
    return { declarations, end: pos };
}
exports.parseDeclarations = parseDeclarations;
function parseDeclaration(src, start, errors) {
    let pos = start + 3; // 'let'
    const ws = (0, util_js_1.whitespaces)(src, pos);
    pos += ws;
    if (ws === 0)
        errors.push({ type: 'missing-char', char: ' ', start: pos });
    let target;
    if (src[pos] === '$') {
        target = (0, values_js_1.parseVariable)(src, pos, errors);
        pos = target.end;
    }
    else {
        const junkStart = pos;
        const junkEndOffset = src.substring(pos).search(/[\t\n\r ={}]/);
        pos = junkEndOffset === -1 ? src.length : pos + junkEndOffset;
        target = {
            type: 'junk',
            start: junkStart,
            end: pos,
            source: src.substring(junkStart, pos)
        };
        errors.push({ type: 'missing-char', char: '$', start: junkStart });
    }
    pos += (0, util_js_1.whitespaces)(src, pos);
    if (src[pos] === '=')
        pos += 1;
    else
        errors.push({ type: 'missing-char', char: '=', start: pos });
    let value;
    pos += (0, util_js_1.whitespaces)(src, pos);
    if (src[pos] === '{') {
        value = (0, placeholder_js_1.parsePlaceholder)(src, pos, errors);
        pos = value.end;
    }
    else {
        const junkStart = pos;
        const junkEndOffset = src
            .substring(pos)
            .search(/\blet|\bmatch|\bwhen|[${}]/);
        pos = junkEndOffset === -1 ? src.length : pos + junkEndOffset;
        value = {
            type: 'junk',
            start: junkStart,
            end: pos,
            source: src.substring(junkStart, pos)
        };
        errors.push({ type: 'missing-char', char: '{', start: junkStart });
    }
    return { start, end: pos, target, value };
}
/** Local variable declarations can't refer to later ones */
function checkLocalVarReferences(declarations, errors) {
    const check = (name, ref) => {
        if (ref.name === name)
            errors.push({ type: 'bad-local-var', start: ref.start, end: ref.end });
    };
    for (let i = 1; i < declarations.length; ++i) {
        const { name } = declarations[i].target;
        if (!name)
            continue;
        for (let j = 0; j < i; ++j) {
            const ph = declarations[j].value;
            if (ph.type === 'placeholder') {
                const exp = ph.body;
                switch (exp.type) {
                    case 'expression':
                        if (exp.operand?.type === 'variable')
                            check(name, exp.operand);
                        for (const opt of exp.options) {
                            if (opt.value.type === 'variable')
                                check(name, opt.value);
                        }
                        break;
                    case 'variable':
                        check(name, exp);
                        break;
                }
            }
        }
    }
}
