"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveExpression = exports.isExpression = void 0;
const message_value_1 = require("../message-value");
const message_value_2 = require("../message-value/message-value");
/**
 * Type guard for {@link Expression} pattern elements
 *
 * @beta
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const isExpression = (part) => !!part && typeof part === 'object' && part.type === 'expression';
exports.isExpression = isExpression;
function resolveExpression(ctx, { operand, name, options }) {
    let source;
    const rf = ctx.runtime[name];
    try {
        let fnArgs;
        if (operand) {
            const arg = ctx.resolve(operand);
            fnArgs = [arg];
            const argSrc = arg.source || (arg.type === 'literal' && arg.value) || message_value_2.FALLBACK_SOURCE;
            source = `${argSrc} :${name}`;
        }
        else {
            fnArgs = [];
            source = `:${name}`;
        }
        if (!rf) {
            const error = new ReferenceError(`Unknown formatter ${name}`);
            throw Object.assign(error, { type: 'missing-func' });
        }
        const opt = { localeMatcher: ctx.localeMatcher };
        if (options) {
            for (const { name, value } of options) {
                opt[name] = ctx.resolve(value).value;
            }
        }
        const res = rf(ctx.locales, opt, ...fnArgs);
        return (0, message_value_1.asMessageValue)(ctx, res, { source });
    }
    catch (error) {
        source ?? (source = `${name}(${operand ? message_value_2.FALLBACK_SOURCE : ''})`);
        const fb = new message_value_1.MessageFallback(ctx, { source });
        ctx.onError(error, fb);
        return fb;
    }
}
exports.resolveExpression = resolveExpression;
