"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolvePatternElement = exports.isPlaceholder = exports.isVariableRef = exports.isMarkupStart = exports.isMarkupEnd = exports.isText = exports.isLiteral = exports.isJunk = exports.isExpression = void 0;
const expression_1 = require("./expression");
const junk_1 = require("./junk");
const literal_1 = require("./literal");
const markup_1 = require("./markup");
const variable_ref_1 = require("./variable-ref");
var expression_2 = require("./expression");
Object.defineProperty(exports, "isExpression", { enumerable: true, get: function () { return expression_2.isExpression; } });
var junk_2 = require("./junk");
Object.defineProperty(exports, "isJunk", { enumerable: true, get: function () { return junk_2.isJunk; } });
var literal_2 = require("./literal");
Object.defineProperty(exports, "isLiteral", { enumerable: true, get: function () { return literal_2.isLiteral; } });
Object.defineProperty(exports, "isText", { enumerable: true, get: function () { return literal_2.isText; } });
var markup_2 = require("./markup");
Object.defineProperty(exports, "isMarkupEnd", { enumerable: true, get: function () { return markup_2.isMarkupEnd; } });
Object.defineProperty(exports, "isMarkupStart", { enumerable: true, get: function () { return markup_2.isMarkupStart; } });
var variable_ref_2 = require("./variable-ref");
Object.defineProperty(exports, "isVariableRef", { enumerable: true, get: function () { return variable_ref_2.isVariableRef; } });
/**
 * Type guard for {@link Placeholder} pattern elements
 *
 * @beta
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const isPlaceholder = (part) => !!part && typeof part === 'object' && part.type === 'placeholder';
exports.isPlaceholder = isPlaceholder;
/** @internal */
function resolvePatternElement(ctx, elem) {
    switch (elem.type) {
        case 'literal':
        case 'nmtoken':
        case 'text':
            return (0, literal_1.resolveLiteral)(elem);
        case 'placeholder':
            return resolvePatternElement(ctx, elem.body);
        case 'variable':
            return (0, variable_ref_1.resolveVariableRef)(ctx, elem);
        case 'expression':
            return (0, expression_1.resolveExpression)(ctx, elem);
        case 'markup-start':
            return (0, markup_1.resolveMarkupStart)(ctx, elem);
        case 'markup-end':
            return (0, markup_1.resolveMarkupEnd)(ctx, elem);
        case 'junk':
            return (0, junk_1.resolveJunk)(ctx, elem);
        default:
            // @ts-expect-error - should never happen
            throw new Error(`Unsupported pattern element: ${elem.type}`);
    }
}
exports.resolvePatternElement = resolvePatternElement;
