import type { Context } from '../format-context';
import { MessageFallback, MessageMarkupEnd, MessageMarkupStart } from '../message-value';
import type { Option } from './index';
/**
 * An element indicating the start of a span of further elements
 * that should have some markup applied to them.
 *
 * @beta
 */
export interface MarkupStart {
    type: 'markup-start';
    name: string;
    options?: Option[];
}
/**
 * An element indicating the end of a span of elements,
 * starting from the most recent {@link MarkupStart} that has the same `name`.
 *
 * @beta
 */
export interface MarkupEnd {
    type: 'markup-end';
    name: string;
}
/**
 * Type guard for {@link MarkupStart} pattern elements
 *
 * @beta
 */
export declare const isMarkupStart: (part: any) => part is MarkupStart;
/**
 * Type guard for {@link MarkupEnd} pattern elements
 *
 * @beta
 */
export declare const isMarkupEnd: (part: any) => part is MarkupEnd;
export declare function resolveMarkupStart(ctx: Context, { name, options }: MarkupStart): MessageFallback | MessageMarkupStart;
export declare function resolveMarkupEnd(ctx: Context, { name }: MarkupEnd): MessageMarkupEnd;
