import { Context } from '../format-context';
import { MessageValue } from '../message-value';
/**
 * The value of a VariableRef is defined by the current Scope.
 *
 * @remarks
 * To refer to an inner property of an object value, use `.` as a separator;
 * in case of conflict, the longest starting substring wins.
 * For example, `'user.name'` would be first matched by an exactly matching top-level key,
 * and in case that fails, with the `'name'` property of the `'user'` object:
 * The runtime scopes `{ 'user.name': 'Kat' }` and `{ user: { name: 'Kat' } }`
 * would both resolve a `'user.name'` VariableRef as the string `'Kat'`.
 *
 * @beta
 */
export interface VariableRef {
    type: 'variable';
    name: string;
}
/**
 * Type guard for {@link VariableRef} pattern elements
 *
 * @beta
 */
export declare const isVariableRef: (part: any) => part is VariableRef;
export declare function resolveVariableRef(ctx: Context, { name }: VariableRef): MessageValue<unknown>;
