"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveVariableRef = exports.isVariableRef = void 0;
const message_value_1 = require("../message-value");
/**
 * Type guard for {@link VariableRef} pattern elements
 *
 * @beta
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const isVariableRef = (part) => !!part && typeof part === 'object' && part.type === 'variable';
exports.isVariableRef = isVariableRef;
const isScope = (scope) => scope instanceof Object && !(scope instanceof message_value_1.MessageValue);
/**
 * Looks for the longest matching `.` delimited starting substring of name.
 * @returns `undefined` if value not found
 */
function getValue(scope, name) {
    if (isScope(scope)) {
        if (name in scope)
            return scope[name];
        const parts = name.split('.');
        for (let i = parts.length - 1; i > 0; --i) {
            const head = parts.slice(0, i).join('.');
            if (head in scope) {
                const tail = parts.slice(i).join('.');
                return getValue(scope[head], tail);
            }
        }
    }
    return undefined;
}
function resolveVariableRef(ctx, { name }) {
    const source = '$' + name;
    let value;
    const decl = ctx.declarations.find(decl => decl.target.name === name);
    if (decl) {
        value = ctx.resolve(decl.value);
        ctx.scope[name] = value;
    }
    else {
        value = getValue(ctx.scope, name);
    }
    if (value !== undefined)
        return (0, message_value_1.asMessageValue)(ctx, value, { source });
    const fb = new message_value_1.MessageFallback(ctx, { source });
    const error = new Error(`Variable not available: ${source}`);
    ctx.onError(Object.assign(error, { type: 'missing-var' }), fb);
    return fb;
}
exports.resolveVariableRef = resolveVariableRef;
