"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.castAsInteger = exports.castAsBoolean = void 0;
/**
 * Utility function for custom functions.
 * Cast resolved option values `'true'` and `'false'` to their Boolean equivalents.
 * Any other values are untouched.
 *
 * @param options Options object, which may be modified.
 * @param names Names of options that should have boolean values.
 */
function castAsBoolean(options, ...names) {
    for (const name of names) {
        const value = options[name];
        if (typeof value === 'string') {
            if (value === 'true')
                options[name] = true;
            else if (value === 'false')
                options[name] = false;
        }
    }
}
exports.castAsBoolean = castAsBoolean;
/**
 * Utility function for custom functions.
 * Cast resolved option values with numerical string representations of integers
 * to their Number equivalents. Any other values are untouched.
 *
 * @param options Options object, which may be modified.
 * @param names Names of options that should have integer values.
 */
function castAsInteger(options, ...names) {
    for (const name of names) {
        const value = options[name];
        if (typeof value === 'string') {
            const num = Number(value);
            if (Number.isInteger(num))
                options[name] = num;
        }
    }
}
exports.castAsInteger = castAsInteger;
